@@ -10,7 +10,6 @@ from typing import Any, Iterator, List, Type, Union
 
 import pytest
 from _pytest.monkeypatch import MonkeyPatch
-from flaky import flaky
 from packaging.version import Version
 from pytest_mock import MockerFixture
 
@@ -213,8 +212,6 @@ def remember_cwd(cwd: str) -> Iterator[None]:
         os.chdir(curdir)
 
 
-# # https://github.com/box/flaky/issues/170
-@flaky(max_runs=3)  # type: ignore
 def test_prerun_reqs_v1(caplog: pytest.LogCaptureFixture, runtime: Runtime) -> None:
     """Checks that the linter can auto-install requirements v1 when found."""
     cwd = os.path.realpath(
@@ -234,7 +231,6 @@ def test_prerun_reqs_v1(caplog: pytest.LogCaptureFixture, runtime: Runtime) -> N
     )
 
 
-@flaky(max_runs=3)  # type: ignore
 def test_prerun_reqs_v2(caplog: pytest.LogCaptureFixture, runtime: Runtime) -> None:
     """Checks that the linter can auto-install requirements v2 when found."""
     cwd = os.path.realpath(
@@ -375,13 +371,13 @@ def test_require_collection_wrong_version(runtime: Runtime) -> None:
             "ansible-galaxy",
             "collection",
             "install",
-            "containers.podman",
+            "examples/reqs_v2/community-molecule-0.1.0.tar.gz",
             "-p",
             "~/.ansible/collections",
         ]
     )
     with pytest.raises(InvalidPrerequisiteError) as pytest_wrapped_e:
-        runtime.require_collection("containers.podman", "9999.9.9")
+        runtime.require_collection("community.molecule", "9999.9.9")
     assert pytest_wrapped_e.type == InvalidPrerequisiteError
     assert pytest_wrapped_e.value.code == INVALID_PREREQUISITES_RC
 
@@ -439,14 +435,16 @@ def test_require_collection_missing(
 
 def test_install_collection(runtime: Runtime) -> None:
     """Check that valid collection installs do not fail."""
-    runtime.install_collection("containers.podman:>=1.0")
+    runtime.install_collection("examples/reqs_v2/community-molecule-0.1.0.tar.gz")
 
 
 def test_install_collection_dest(runtime: Runtime, tmp_path: pathlib.Path) -> None:
     """Check that valid collection to custom destination passes."""
-    runtime.install_collection("containers.podman:>=1.0", destination=tmp_path)
+    runtime.install_collection(
+        "examples/reqs_v2/community-molecule-0.1.0.tar.gz", destination=tmp_path
+    )
     expected_file = (
-        tmp_path / "ansible_collections" / "containers" / "podman" / "MANIFEST.json"
+        tmp_path / "ansible_collections" / "community" / "molecule" / "MANIFEST.json"
     )
     assert expected_file.is_file()
 
@@ -454,7 +452,7 @@ def test_install_collection_dest(runtime: Runtime, tmp_path: pathlib.Path) -> No
 def test_install_collection_fail(runtime: Runtime) -> None:
     """Check that invalid collection install fails."""
     with pytest.raises(AnsibleCompatError) as pytest_wrapped_e:
-        runtime.install_collection("containers.podman:>=9999.0")
+        runtime.install_collection("community.molecule:>=9999.0")
     assert pytest_wrapped_e.type == InvalidPrerequisiteError
     assert pytest_wrapped_e.value.code == INVALID_PREREQUISITES_RC
 
@@ -564,15 +562,15 @@ def test_upgrade_collection(runtime_tmp: Runtime) -> None:
     runtime_tmp.prepare_environment()
 
     # we install specific oudated version of a collection
-    runtime_tmp.install_collection("containers.podman:==1.6.0")
+    runtime_tmp.install_collection("examples/reqs_v2/community-molecule-0.1.0.tar.gz")
     with pytest.raises(
         InvalidPrerequisiteError,
-        match="Found containers.podman collection 1.6.0 but 1.6.1 or newer is required.",
+        match="Found community.molecule collection 0.1.0 but 9.9.9 or newer is required.",
     ):
         # we check that when install=False, we raise error
-        runtime_tmp.require_collection("containers.podman", "1.6.1", install=False)
-    # now we really perform the upgrade
-    runtime_tmp.require_collection("containers.podman", "1.6.1")
+        runtime_tmp.require_collection("community.molecule", "9.9.9", install=False)
+    # this should not fail, as we have this version
+    runtime_tmp.require_collection("community.molecule", "0.1.0")
 
 
 def test_require_collection_no_cache_dir() -> None:
@@ -662,8 +660,7 @@ def test_prepare_environment_offline_role() -> None:
     """Ensure that we can make use of offline roles."""
     with remember_cwd("test/roles/acme.missing_deps"):
         runtime = Runtime(isolated=True)
-        with pytest.raises(AnsibleCommandError):
-            runtime.prepare_environment(install_local=True, offline=True)
+        runtime.prepare_environment(install_local=True, offline=True)
 
 
 def test_runtime_run(runtime: Runtime) -> None:
